/***********************************************************
** Hamaguchi, Nobuaki and Keisuke Kondo (2018)
** "Regional employment and artificial intelligence in Japan"
**
** [Replication Code]
** Uploaded Data: May 16, 2018
***********************************************************/


** Log
log using "log/LOG_STEP1-1_estimation_score_all.smcl", replace smcl


** Load
use "data_pref/DTA_census_all.dta", clear


** Merge with Occupation Code
merge 1:1 id_occ using "data_prob_occ/DTA_prob_occ.dta", keepusing(id_occ_3d_new mean_prob median_prob min_prob max_prob)
drop if _merge == 2
drop _merge

** Others in Occupation
gen d_other_occ = .
replace d_other_occ = 1 if substr(id_occ_3d_new, 3, 1) == "V"
replace d_other_occ = 1 if id_occ == 232

** Drop
drop if d_other_occ == 1

** Order
order id_occ_3d_new, before(d_other_occ)

** Share within 47 prefectures
count
local cN = r(N) + 1
set obs `cN'
replace id_occ = 0 if _n == _N
replace name_occ_3d = "総数" if id_occ == 0

egen total = total(nation)
replace nation = total if id_occ == 0
drop total
forvalue i = 1(1)47 {
	egen total = total(pref`i')
	replace pref`i' = total if id_occ == 0
	drop total
}
sort id_occ

gen share_nation = nation / nation[1]
forvalue i = 1(1)47 {
	gen share_pref`i' = pref`i' / pref`i'[1]
}


** Score by Occupation
gen score_nation = share_nation * mean_prob * 100
forvalue i = 1(1)47 {
	gen score_pref`i' = share_pref`i' * mean_prob * 100
}

** Score Summary by Prefecture
egen total = total(score_nation)
replace score_nation = total if id_occ == 0
drop total
forvalue i = 1(1)47 {
	egen total = total(score_pref`i')
	replace score_pref`i' = total if id_occ == 0
	drop total
}


** Save
save "DTA_census_score_all.dta", replace	
	
	
log close

	
