/***********************************************************
** Hamaguchi, Nobuaki and Keisuke Kondo (2018)
** "Regional employment and artificial intelligence in Japan"
**
** [Replication Code]
** Uploaded Data: May 16, 2018
**
** [Previous Do-File] DO_STEP1_estimation_score.do
***********************************************************/


** Log
log using "log/LOG_STEP2_score_pdens.smcl", replace smcl

/*
** ==========================
** Score Summary
** 
** ==========================
*/

clear
** Matrix
matrix mScore = J(48,4,0)
forvalues i = 0(1)47 {
	local j = `i' + 1
	matrix mScore[`j',1] = `i'
}

/*
** +++++++++++
** All
** +++++++++++
*/ 
** Load
use "DTA_census_score_all.dta", clear
keep if id_occ == 0
keep score_nation score_pref*

matrix mScore[1,2] = score_nation[1]
forvalues i = 1(1)47 {
	local j = `i' + 1
	matrix mScore[`j',2] = score_pref`i'[1]
}

/*
** +++++++++++
** Male
** +++++++++++
*/ 
** Load
use "DTA_census_score_male.dta", clear
keep if id_occ == 0
keep score_nation score_pref*

matrix mScore[1,3] = score_nation[1]
forvalues i = 1(1)47 {
	local j = `i' + 1
	matrix mScore[`j',3] = score_pref`i'[1]
}

/*
** +++++++++++
** Female
** +++++++++++
*/ 
** Load
use "DTA_census_score_female.dta", clear
keep if id_occ == 0
keep score_nation score_pref*

matrix mScore[1,4] = score_nation[1]
forvalues i = 1(1)47 {
	local j = `i' + 1
	matrix mScore[`j',4] = score_pref`i'[1]
}

**
matrix list mScore

/*
** +++++++++++
** Merge
** +++++++++++
*/ 
clear
svmat mScore

**
rename mScore1 id_pref
rename mScore2 score_all
rename mScore3 score_male
rename mScore4 score_female

**
merge 1:1 id_pref using "data_pref/DTA_census_pdens.dta"
drop _merge

** Variable
gen ratio = score_female/score_male
gen lnpdens = log( pdens )

** Save
save "DTA_score_pdens.dta", replace

/*
** ==========================
** Figure
** 
** ==========================
*/

**
drop if id_pref == 0

** Scatter
twoway (scatter ratio lnpdens, ms(Oh)) /*
		*/ (lfit ratio lnpdens, lwidth(medthick)) /*
		*/ (scatter ratio lnpdens, mlab(name_pref_en) mlabc(dknavy) mlabs(medlarge) mlabp(12) mc(none)), /*
		*/ ytitle("Risk Score Ratio (Female/Male)", tstyle(size(vlarge))) /*
		*/ xtitle("Log(Population Density)", tstyle(size(vlarge)) /*
		*/ height(7)) ysize(3) xsize(4) /*
		*/ ylabel(, ang(h) labsize(vlarge) format(%3.2f) nogrid) /*
		*/ xlabel(, labsize(vlarge) format(%2.1f)) legend(off) /*
		*/ yline(1, lwidth(thin) lcolor(gray) lpattern(dash)) /*
		*/ graphregion(color(white) fcolor(white))
graph export "fig_en/FIG_scatter_ratio_pdens.eps", fontface("Palatino Linotype") replace

** Scatter: Score Male
twoway (scatter score_male lnpdens, ms(Oh)) /*
		*/ (lfit score_male lnpdens, lwidth(medthick)) /*
		*/ (scatter score_male lnpdens, mlab(name_pref_en) mlabc(dknavy) mlabs(medlarge) mlabp(12) mc(none)), /*
		*/ ytitle("Risk Score (Male)", tstyle(size(vlarge))) /*
		*/ xtitle("Log(Population Density)", tstyle(size(vlarge)) height(7)) ysize(3) xsize(4) /*
		*/ ylabel(58(4)70, ang(h) labsize(vlarge) format(%3.0f) nogrid) /*
		*/ xlabel(, labsize(vlarge) format(%2.1f)) legend(off) /*
		*/ graphregion(color(white) fcolor(white))
graph export "fig_en/FIG_scatter_score_male_pdens.eps", fontface("Palatino Linotype") replace


** Scatter: Score Female
twoway (scatter score_female lnpdens, ms(Oh)) /*
		*/ (lfit score_female lnpdens, lwidth(medthick)) /*
		*/ (scatter score_female lnpdens, mlab(name_pref_en) mlabc(dknavy) mlabs(medlarge) mlabp(12) mc(none)), /*
		*/ ytitle("Risk Score (Female)", tstyle(size(vlarge))) /*
		*/ xtitle("Log(Population Density)", tstyle(size(vlarge)) height(7)) ysize(3) xsize(4) /*
		*/ ylabel(58(4)70, ang(h) labsize(vlarge) format(%3.0f) nogrid) /*
		*/ xlabel(, labsize(vlarge) format(%2.1f)) legend(off) /*
		*/ graphregion(color(white) fcolor(white))
graph export "fig_en/FIG_scatter_score_female_pdens.eps", fontface("Palatino Linotype") replace



/*
** ==========================
** Regression
** 
** ==========================
*/

**
reg ratio lnpdens

**
reg score_male lnpdens

**
reg score_female lnpdens



log close

	
